@@ -102,13 +102,13 @@ var NAVTREEINDEX =
 [
 "annotated.html",
 "core_8h.html#a3c4c5529b9bb6c9188053bdf1604c2e0",
-"global_8h.html#a3e5b2dd59d6cf7c614c3ed24b041a8b7",
-"impl-node_8c.html#a2a6221b4e79357e3d2620faf0e2c7623",
-"link_8h.html#a72d8e03483fd111c9a9eb87aac3897a2",
-"permission_8h.html#a50224a8e3d16e9baa4be58183fec502f",
-"stream_8h.html#a087a686c66c04e54742cc94c7a5e4e68",
-"structpw__factory__events.html#a2408a490257998e8aec63c452b450024",
-"structpw__protocol__events.html#af7bb9abb40f974acecda6bb2c6ad5cad"
+"global_8h.html#a3c30e6a36a12ab02e97c7a0014d578d0",
+"impl-node_8c.html#a0c09f345941b97bd6bc796ee014214f0",
+"link_8h.html#a481b4d0b9cd49478fd13dc8934478840",
+"pages.html",
+"stream_8h.html#a058907c2dffbb8fb5ede8a53d7604106a2912e7520b8eb0aa5e4a5ca275f10d3b",
+"structpw__device__info.html#accce9f7bcbbb1e5142298f18ce03d799",
+"structpw__properties.html#aef040055887634f636bb26594091c31c"
 ];
 
 var SYNCONMSG = 'click to disable panel synchronisation';
